<?php

/**
* Smarty Internal Plugin Resource Registered
* 
* Implements the registered resource for Smarty template
* 
* @package Smarty
* @subpackage TemplateResources
* @author Uwe Tews 
*/
/**
* Smarty Internal Plugin Resource Registered
*/

class Smarty_Internal_Resource_Registered {
    public function __construct($smarty)
    {
        $this->smarty = $smarty;
    } 
    // classes used for compiling Smarty templates from file resource
    public $compiler_class = 'Smarty_Internal_SmartyTemplateCompiler';
    public $template_lexer_class = 'Smarty_Internal_Templatelexer';
    public $template_parser_class = 'Smarty_Internal_Templateparser';

    /**
    * Return flag if template source is existing
    * 
    * @return boolean true
    */
    public function isExisting($_template)
    {
        if (is_integer($this->getTemplateTimestamp($_template))) {
            return true;
        } else {
            return false;
        } 
    } 
    /**
    * Get filepath to template source
    * 
    * @param object $_template template object
    * @return string return 'string' as template source is not a file
    */
    public function getTemplateFilepath($_template)
    { 
        // no filepath for strings
        // return "string" for compiler error messages
           $_filepath = $_template->resource_type .':'.$_template->resource_name;

        return $_filepath;
 } 

    /**
    * Get timestamp to template source
    * 
    * @param object $_template template object
    * @return boolean false as string resources have no timestamp
    */
    public function getTemplateTimestamp($_template)
    { 
        // return timestamp
        $time_stamp = false;
        call_user_func_array($this->smarty->_plugins['resource'][$_template->resource_type][0][1],
            array($_template->resource_name, &$time_stamp, $this->smarty));
        return $time_stamp;
    } 
    /**
    * Get timestamp to template source by type and name
    * 
    * @param object $_template template object
    * @return boolean false as string resources have no timestamp
    */
    public function getTemplateTimestampTypeName($_resource_type, $_resource_name)
    { 
        // return timestamp
        $time_stamp = false;
        call_user_func_array($this->smarty->_plugins['resource'][$_resource_type][0][1],
            array($_resource_name, &$time_stamp, $this->smarty));
        return $time_stamp;
    } 

    /**
    * Retuen template source from resource name
    * 
    * @param object $_template template object
    * @return string content of template source
    */
    public function getTemplateSource($_template)
    { 
        // return template string
        return call_user_func_array($this->smarty->_plugins['resource'][$_template->resource_type][0][0],
            array($_template->resource_name, &$_template->template_source, $this->smarty));
    } 

    /**
    * Return flag that this resource uses the compiler
    * 
    * @return boolean true
    */
    public function usesCompiler()
    { 
        // resource string is template, needs compiler
        return true;
    } 

    /**
    * Return flag that this resource is evaluated
    * 
    * @return boolean true
    */
    public function isEvaluated()
    { 
        // compiled template is evaluated instead of saved to disk
        return false;
    } 

    /**
    * Get filepath to compiled template
    * 
    * @param object $_template template object
    * @return boolean return false as compiled template is not stored
    */
    public function getCompiledFilepath($_template)
    { 
        // $_filepath = md5($_template->resource_name);
        $_filepath = (string)abs(crc32($_template->template_resource)); 
        // if use_sub_dirs, break file into directories
        if ($_template->smarty->use_sub_dirs) {
            $_filepath = substr($_filepath, 0, 3) . DS
             . substr($_filepath, 0, 2) . DS
             . substr($_filepath, 0, 1) . DS
             . $_filepath;
        } 
        $_compile_dir_sep = $_template->smarty->use_sub_dirs ? DS : '^';
        if (isset($_template->compile_id)) {
            $_filepath = $_template->compile_id . $_compile_dir_sep . $_filepath;
        } 
        if ($_template->caching) {
            $_cache = '.cache';
        } else {
            $_cache = '';
        } 
        $_compile_dir = $_template->smarty->compile_dir;
        if (strpos('/\\', substr($_compile_dir, -1)) === false) {
            $_compile_dir .= DS;
        } 
        return $_compile_dir . $_filepath . '.' . $_template->resource_type . '.' . basename($_template->resource_name) . $_cache . $_template->smarty->php_ext;
    } 
} 

?>
